# Credits

## Development Lead

-   Andrea Mucci <andrea@clariteia.com>

## Contributors

-   Alberto Amigo <alberto.amigo@clariteia.com>
-   Sergio Garcia Prado <sergio.garcia@clariteia.com>
-   Vladyslav Fenchak <vladyslav.fenchak@clariteia.com>
